package com.trafficparrot.sdk;

import com.github.jknack.handlebars.Helper;
import com.github.jknack.handlebars.Options;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.io.IOException;

import static java.lang.String.format;

public abstract class TrafficParrotHelper<T> implements Helper<T> {
    private static final Logger LOGGER = LoggerFactory.getLogger(TrafficParrotHelper.class);

    @Override
    public Object apply(T t, Options options) throws IOException {
        try {
            return doApply(t, options);
        } catch (Exception e) {
            String msg = format("%s had a problem while transforming: %s", getClass().getCanonicalName(), e.getMessage());
            LOGGER.error(msg, e);
            return msg;
        }
    }

    protected abstract Object doApply(T t, Options options) throws IOException;

    public String getName() {
        String name = getClass().getSimpleName().replaceAll("Helper$", "");
        return name.substring(0, 1).toLowerCase() + name.substring(1);
    }
}
